@@ -1569,3 +1569,29 @@ class TestDuckDB(Validator):
             """,
             "SELECT l_returnflag, l_linestatus, SUM(l_quantity) AS sum_qty, SUM(l_extendedprice) AS sum_base_price, SUM(l_extendedprice * (1 - l_discount)) AS sum_disc_price, SUM(l_extendedprice * (1 - l_discount) * (1 + l_tax)) AS sum_charge, AVG(l_quantity) AS avg_qty, AVG(l_extendedprice) AS avg_price, AVG(l_discount) AS avg_disc, COUNT(*) AS count_order",
         )
+
+    def test_at_sign_to_abs(self):
+        self.validate_identity(
+            "SELECT @col FROM t",
+            "SELECT ABS(col) FROM t",
+        )
+        self.validate_identity(
+            "SELECT @col + 1 FROM t",
+            "SELECT ABS(col + 1) FROM t",
+        )
+        self.validate_identity(
+            "SELECT (@col) + 1 FROM t",
+            "SELECT (ABS(col)) + 1 FROM t",
+        )
+        self.validate_identity(
+            "SELECT @(-1)",
+            "SELECT ABS((-1))",
+        )
+        self.validate_identity(
+            "SELECT @(-1) + 1",
+            "SELECT ABS((-1) + 1)",
+        )
+        self.validate_identity(
+            "SELECT (@-1) + 1",
+            "SELECT (ABS(-1)) + 1",
+        )
